( cd usr/lib ; rm -rf libgnomevfsmm-2.6.so.1 )
( cd usr/lib ; ln -sf libgnomevfsmm-2.6.so.1.0.5 libgnomevfsmm-2.6.so.1 )
( cd usr/lib ; rm -rf libgnomevfsmm-2.6.so )
( cd usr/lib ; ln -sf libgnomevfsmm-2.6.so.1.0.5 libgnomevfsmm-2.6.so )
