// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _LIBGNOMEVFSMM_VOLUME_H
#define _LIBGNOMEVFSMM_VOLUME_H

#include <glibmm.h>

/* Copyright 2003 gnome-vfsmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <libgnomevfsmm/enums.h>

#ifndef DOXYGEN_SHOULD_SKIP_THIS
typedef struct _GnomeVFSVolume GnomeVFSVolume;
typedef struct _GnomeVFSVolumeClass GnomeVFSVolumeClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


namespace Gnome
{

namespace Vfs
{ class Volume_Class; } // namespace Vfs

} // namespace Gnome
namespace Gnome
{

namespace Vfs
{

class Drive;


class Volume : public Glib::Object
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  typedef Volume CppObjectType;
  typedef Volume_Class CppClassType;
  typedef GnomeVFSVolume BaseObjectType;
  typedef GnomeVFSVolumeClass BaseClassType;

private:  friend class Volume_Class;
  static CppClassType volume_class_;

private:
  // noncopyable
  Volume(const Volume&);
  Volume& operator=(const Volume&);

protected:
  explicit Volume(const Glib::ConstructParams& construct_params);
  explicit Volume(GnomeVFSVolume* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:
  virtual ~Volume();

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  static GType get_type()      G_GNUC_CONST;
  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GnomeVFSVolume*       gobj()       { return reinterpret_cast<GnomeVFSVolume*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GnomeVFSVolume* gobj() const { return reinterpret_cast<GnomeVFSVolume*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GnomeVFSVolume* gobj_copy();

private:

  
public:

  /** For instance,
   * void on_operation(bool succeeded, const Glib::ustring& error, const Glib::ustring& detailed_error);
   */
  typedef sigc::slot<void, bool, Glib::ustring, Glib::ustring> OpSlot;
  
  
  gulong get_id() const;
  
  VolumeType get_volume_type() const;
  
  DeviceType get_device_type() const;
  
  Glib::RefPtr<Drive> get_drive() const;
  
  Glib::ustring get_device_path() const;
  
  Glib::ustring get_activation_uri() const;
  
  Glib::ustring get_filesystem_type() const;
  
  Glib::ustring get_display_name() const;
  
  Glib::ustring get_icon() const;
  //gtkmmproc error: gnome_vfs_volme_get_hal_udi : method defs lookup failed (1)
  
  bool is_user_visible() const;
  
  bool is_read_only() const;
  
  bool is_mounted() const;
  
  bool handles_trash() const;
  
  
  static int compare(const Glib::RefPtr<const Volume>& a, const Glib::RefPtr<const Volume>& b);
  

  void unmount(const OpSlot& slot);
  void eject(const OpSlot& slot);
 
  
  static void connect_to_server(const Glib::ustring& uri, const Glib::ustring& display_name, const Glib::ustring& icon);


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};
  

} // namespace Vfs
} // namespace Gnome


namespace Glib
{
  /** @relates Gnome::Vfs::Volume
   * @param object The C instance
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   */
  Glib::RefPtr<Gnome::Vfs::Volume> wrap(GnomeVFSVolume* object, bool take_copy = false);
}


#endif /* _LIBGNOMEVFSMM_VOLUME_H */

