// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _LIBGNOMEVFSMM_VOLUME_MONITOR_H
#define _LIBGNOMEVFSMM_VOLUME_MONITOR_H

#include <glibmm.h>

/* Copyright 2003 gnome-vfsmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <libgnomevfsmm/drive.h>
#include <libgnomevfsmm/volume.h>

#ifndef DOXYGEN_SHOULD_SKIP_THIS
typedef struct _GnomeVFSVolumeMonitor GnomeVFSVolumeMonitor;
typedef struct _GnomeVFSVolumeMonitorClass GnomeVFSVolumeMonitorClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


namespace Gnome
{

namespace Vfs
{ class VolumeMonitor_Class; } // namespace Vfs

} // namespace Gnome
namespace Gnome
{

namespace Vfs
{


class VolumeMonitor : public Glib::Object
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  typedef VolumeMonitor CppObjectType;
  typedef VolumeMonitor_Class CppClassType;
  typedef GnomeVFSVolumeMonitor BaseObjectType;
  typedef GnomeVFSVolumeMonitorClass BaseClassType;

private:  friend class VolumeMonitor_Class;
  static CppClassType volumemonitor_class_;

private:
  // noncopyable
  VolumeMonitor(const VolumeMonitor&);
  VolumeMonitor& operator=(const VolumeMonitor&);

protected:
  explicit VolumeMonitor(const Glib::ConstructParams& construct_params);
  explicit VolumeMonitor(GnomeVFSVolumeMonitor* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:
  virtual ~VolumeMonitor();

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  static GType get_type()      G_GNUC_CONST;
  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GnomeVFSVolumeMonitor*       gobj()       { return reinterpret_cast<GnomeVFSVolumeMonitor*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GnomeVFSVolumeMonitor* gobj() const { return reinterpret_cast<GnomeVFSVolumeMonitor*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GnomeVFSVolumeMonitor* gobj_copy();

private:

  
public:
  
  
  static Glib::RefPtr<VolumeMonitor> create();
  
  
  Glib::ListHandle< Glib::RefPtr<Volume> > get_mounted_volumes();
  
  Glib::ListHandle< Glib::RefPtr<const Volume> > get_mounted_volumes() const;

  
  Glib::ListHandle< Glib::RefPtr<Drive> > get_connected_drives();
  
  Glib::ListHandle< Glib::RefPtr<const Drive> > get_connected_drives() const;

  
  Glib::RefPtr<Volume> get_volume(const Glib::ustring& path);
  
  Glib::RefPtr<const Volume> get_volume(const Glib::ustring& path) const;
  
  Glib::RefPtr<Volume> get_volume(gulong id);
  
  Glib::RefPtr<const Volume> get_volume(gulong id) const;
  
  Glib::RefPtr<Drive> get_drive(gulong id);
  
  Glib::RefPtr<const Drive> get_drive(gulong id) const;

  
  Glib::SignalProxy1< void,const Glib::RefPtr<Volume>& > signal_volume_mounted();

  
  Glib::SignalProxy1< void,const Glib::RefPtr<Volume>& > signal_volume_pre_unmount();

  
  Glib::SignalProxy1< void,const Glib::RefPtr<Volume>& > signal_volume_unmounted();


  Glib::SignalProxy1< void,const Glib::RefPtr<Drive>& > signal_drive_connected();

  
  Glib::SignalProxy1< void,const Glib::RefPtr<Drive>& > signal_drive_disconnected();


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::
  virtual void on_volume_mounted(const Glib::RefPtr<Volume>& volume);
  virtual void on_volume_pre_unmount(const Glib::RefPtr<Volume>& volume);
  virtual void on_volume_unmounted(const Glib::RefPtr<Volume>& volume);
  virtual void on_drive_connected(const Glib::RefPtr<Drive>& drive);
  virtual void on_drive_disconnected(const Glib::RefPtr<Drive>& drive);


};
  

} // namespace Vfs
} // namespace Gnome


namespace Glib
{
  /** @relates Gnome::Vfs::VolumeMonitor
   * @param object The C instance
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   */
  Glib::RefPtr<Gnome::Vfs::VolumeMonitor> wrap(GnomeVFSVolumeMonitor* object, bool take_copy = false);
}


#endif /* _LIBGNOMEVFSMM_VOLUME_MONITOR_H */

