// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _LIBGNOMEVFSMM_ADDRESS_H
#define _LIBGNOMEVFSMM_ADDRESS_H

#include <glibmm.h>

/* Copyright 2003 gnome-vfsmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <libgnomevfs/gnome-vfs-address.h>

#include <libgnomevfsmm/enums.h>
#include <libgnomevfsmm/exception.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
extern "C" { typedef struct _GnomeVFSAddress GnomeVFSAddress; }
#endif

namespace Gnome
{

namespace Vfs
{

class Address
{
  public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  typedef Address CppObjectType;
  typedef GnomeVFSAddress BaseObjectType;

  static GType get_type() G_GNUC_CONST;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  Address();

  explicit Address(GnomeVFSAddress* gobject, bool make_a_copy = true);

  Address(const Address& other);
  Address& operator=(const Address& other);

  ~Address();

  void swap(Address& other);

  ///Provides access to the underlying C instance.
  GnomeVFSAddress*       gobj()       { return gobject_; }

  ///Provides access to the underlying C instance.
  const GnomeVFSAddress* gobj() const { return gobject_; }

  ///Provides access to the underlying C instance. The caller is responsible for freeing it. Use when directly setting fields in structs.
  GnomeVFSAddress* gobj_copy() const;

protected:
  GnomeVFSAddress* gobject_;

private:

public:
  

public:
  explicit Address(const Glib::ustring& address);
  explicit Address(guint32 ipv4_address);
  explicit Address(struct sockaddr* sa, int len);

  
  int get_family_type() const;
  
  Glib::ustring to_string() const;
  
  guint32 get_ipv4() const;
  //gtkmmproc error: gnome_vfs_address_get_sockaddr : method defs lookup failed (1)

  GnomeVFSAddress** gobj_addr()  { return &gobject_; }
  

};

} // namespace Vfs
} // namespace Gnome


namespace Gnome
{

namespace Vfs
{

/** @relates Gnome::Vfs::Address
 * @param lhs The left-hand side
 * @param rhs The right-hand side
 */
inline void swap(Address& lhs, Address& rhs)
  { lhs.swap(rhs); }

} // namespace Vfs

} // namespace Gnome

namespace Glib
{

/** @relates Gnome::Vfs::Address
 * @param object The C instance
 * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
 * @result A C++ instance that wraps this C instance.
 */
Gnome::Vfs::Address wrap(GnomeVFSAddress* object, bool take_copy = false);

#ifndef DOXYGEN_SHOULD_SKIP_THIS
template <>
class Value<Gnome::Vfs::Address> : public Glib::Value_Boxed<Gnome::Vfs::Address>
{};
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

} // namespace Glib

#endif /* _LIBGNOMEVFSMM_ADDRESS_H */

