// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _LIBGNOMEVFSMM_VOLUME_MONITOR_P_H
#define _LIBGNOMEVFSMM_VOLUME_MONITOR_P_H
#include <glibmm/private/object_p.h>

#include <glibmm/class.h>

namespace Gnome
{

namespace Vfs
{

class VolumeMonitor_Class : public Glib::Class
{
public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  typedef VolumeMonitor CppObjectType;
  typedef GnomeVFSVolumeMonitor BaseObjectType;
  typedef GnomeVFSVolumeMonitorClass BaseClassType;
  typedef Glib::Object_Class CppClassParent;
  typedef GObjectClass BaseClassParent;

  friend class VolumeMonitor;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  const Glib::Class& init();

  static void class_init_function(void* g_class, void* class_data);

  static Glib::ObjectBase* wrap_new(GObject*);

protected:

  //Callbacks (default signal handlers):
  //These will call the *_impl member methods, which will then call the existing default signal callbacks, if any.
  //You could prevent the original default signal handlers being called by overriding the *_impl method.
  static void volume_mounted_callback(GnomeVFSVolumeMonitor* self, GnomeVFSVolume* p0);
  static void volume_pre_unmount_callback(GnomeVFSVolumeMonitor* self, GnomeVFSVolume* p0);
  static void volume_unmounted_callback(GnomeVFSVolumeMonitor* self, GnomeVFSVolume* p0);
  static void drive_connected_callback(GnomeVFSVolumeMonitor* self, GnomeVFSDrive* p0);
  static void drive_disconnected_callback(GnomeVFSVolumeMonitor* self, GnomeVFSDrive* p0);

  //Callbacks (virtual functions):
};


} // namespace Vfs

} // namespace Gnome

#endif /* _LIBGNOMEVFSMM_VOLUME_MONITOR_P_H */

