/* libgnomevfs/libgnomevfsmmconfig.h.  Generated by configure.  */
#ifndef _GNOME_VFSMM_CONFIG_H
#define _GNOME_VFSMM_CONFIG_H 1

#include "glibmmconfig.h"

/* version numbers */
/* #undef GNOME_VFSMM_MAJOR_VERSION */
/* #undef GNOME_VFSMM_MINOR_VERSION */
/* #undef GNOME_VFSMM_MICRO_VERSION */
/* #undef GNOME_VFSMM_VERSION */

#endif /* _GNOME_VFSMM_CONFIG_H */

