// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _LIBGNOMEVFSMM_DRIVE_H
#define _LIBGNOMEVFSMM_DRIVE_H

#include <glibmm.h>

/* Copyright 2003 gnome-vfsmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <libgnomevfsmm/enums.h>

#ifndef DOXYGEN_SHOULD_SKIP_THIS
typedef struct _GnomeVFSDrive GnomeVFSDrive;
typedef struct _GnomeVFSDriveClass GnomeVFSDriveClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


namespace Gnome
{

namespace Vfs
{ class Drive_Class; } // namespace Vfs

} // namespace Gnome
namespace Gnome
{

namespace Vfs
{

class Volume;


class Drive : public Glib::Object
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  typedef Drive CppObjectType;
  typedef Drive_Class CppClassType;
  typedef GnomeVFSDrive BaseObjectType;
  typedef GnomeVFSDriveClass BaseClassType;

private:  friend class Drive_Class;
  static CppClassType drive_class_;

private:
  // noncopyable
  Drive(const Drive&);
  Drive& operator=(const Drive&);

protected:
  explicit Drive(const Glib::ConstructParams& construct_params);
  explicit Drive(GnomeVFSDrive* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:
  virtual ~Drive();

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  static GType get_type()      G_GNUC_CONST;
  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GnomeVFSDrive*       gobj()       { return reinterpret_cast<GnomeVFSDrive*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GnomeVFSDrive* gobj() const { return reinterpret_cast<GnomeVFSDrive*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GnomeVFSDrive* gobj_copy();

private:

  
public:
            
  /** For instance,
   * void on_operation(bool succeeded, const Glib::ustring& error, const Glib::ustring& detailed_error);
   */
  typedef sigc::slot<void, bool, const Glib::ustring&, const Glib::ustring&> OpSlot;
  
  
  gulong get_id() const;
  
  DeviceType get_device_type() const;
  
  Glib::RefPtr<Volume> get_mounted_volume();
  
  Glib::RefPtr<const Volume> get_mounted_volume() const;
  
  Glib::ustring get_device_path() const;
  
  Glib::ustring get_activation_uri() const;
  
  Glib::ustring get_display_name() const;
  
  Glib::ustring get_icon() const;
  
  Glib::ustring get_hal_udi() const;
  
  bool is_user_visible() const;
  
  bool is_connected() const;
  
  bool is_mounted() const;

  //We could wrap this as operator==() instead, but that would need RefPtr::operator*. murrayc.
  
  static int compare(const Glib::RefPtr<const Drive>& a, const Glib::RefPtr<const Drive>& b);
  

  void mount(const OpSlot& slot);
  void unmount(const OpSlot& slot);
  void eject(const OpSlot& slot);

  
  Glib::SignalProxy1< void,const Glib::RefPtr<Volume>& > signal_mounted();

  
  Glib::SignalProxy1< void,const Glib::RefPtr<Volume>& > signal_pre_unmount();

  
  Glib::SignalProxy1< void,const Glib::RefPtr<Volume>& > signal_unmounted();


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::
  virtual void on_mounted(const Glib::RefPtr<Volume>& volume);
  virtual void on_pre_unmount(const Glib::RefPtr<Volume>& volume);
  virtual void on_unmounted(const Glib::RefPtr<Volume>& volume);


};
  

} // namespace Vfs
} // namespace Gnome


namespace Glib
{
  /** @relates Gnome::Vfs::Drive
   * @param object The C instance
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   */
  Glib::RefPtr<Gnome::Vfs::Drive> wrap(GnomeVFSDrive* object, bool take_copy = false);
}


#endif /* _LIBGNOMEVFSMM_DRIVE_H */

