// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _LIBGNOMEVFSMM_MIME_ACTION_H
#define _LIBGNOMEVFSMM_MIME_ACTION_H

#include <glibmm.h>

/* Copyright 2003 gnome-vfsmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <libgnomevfs/gnome-vfs-mime-handlers.h>

#include <libgnomevfsmm/enums.h>
#include <libgnomevfsmm/exception.h>


namespace Gnome
{

namespace Vfs
{

class MimeAction
{
  public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  typedef MimeAction CppObjectType;
  typedef GnomeVFSMimeAction BaseObjectType;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

private:

  
public:
  MimeAction();
  ~MimeAction();

  GnomeVFSMimeAction*       gobj()       { return gobject_; }
  const GnomeVFSMimeAction* gobj() const { return gobject_; }

  
  void launch(const Glib::ListHandle<Glib::ustring>& uris) throw(exception);
  void launch(const Glib::ListHandle<Glib::ustring>& uris, const Glib::ustring& envp) throw(exception);

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  void assign_gobj(GnomeVFSMimeAction* src);
#endif

protected:
  GnomeVFSMimeAction* gobject_;
  
private:
  //Instances of this class can not be copied:
  MimeAction(const MimeAction&);
  MimeAction& operator=(const MimeAction&);


};

} // namespace Vfs
} // namespace Gnome

#endif /* _LIBGNOMEVFSMM_MIME_ACTION_H */

