// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _LIBGNOMEVFSMM_MIME_MONITOR_H
#define _LIBGNOMEVFSMM_MIME_MONITOR_H

#include <glibmm.h>

/* $Id: mime-monitor.hg,v 1.3 2004/04/07 17:39:05 murrayc Exp $ */
// -*- C++ -*- // this is for the .hg, I realize gensig puts one in

/* mime-monitor.h
 *
 * Copyright 2003 gnome-vfsmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <glibmm/object.h>
#include <libgnomevfs/gnome-vfs-mime-monitor.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


namespace Gnome
{

namespace Vfs
{ class MimeMonitor_Class; } // namespace Vfs

} // namespace Gnome
namespace Gnome
{
  
namespace Vfs
{


class MimeMonitor : public Glib::Object
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  typedef MimeMonitor CppObjectType;
  typedef MimeMonitor_Class CppClassType;
  typedef GnomeVFSMIMEMonitor BaseObjectType;
  typedef GnomeVFSMIMEMonitorClass BaseClassType;

private:  friend class MimeMonitor_Class;
  static CppClassType mimemonitor_class_;

private:
  // noncopyable
  MimeMonitor(const MimeMonitor&);
  MimeMonitor& operator=(const MimeMonitor&);

protected:
  explicit MimeMonitor(const Glib::ConstructParams& construct_params);
  explicit MimeMonitor(GnomeVFSMIMEMonitor* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:
  virtual ~MimeMonitor();

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  static GType get_type()      G_GNUC_CONST;
  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GnomeVFSMIMEMonitor*       gobj()       { return reinterpret_cast<GnomeVFSMIMEMonitor*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GnomeVFSMIMEMonitor* gobj() const { return reinterpret_cast<GnomeVFSMIMEMonitor*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GnomeVFSMIMEMonitor* gobj_copy();

private:

   //TODO: Remove this and remove the #include when the struct declaration is fixed in gnome-vfs.
public:
  
  /** Get access to the single global monitor.
   * @return The global Gnome::VFSMIMEMonitor.
   */
  static Glib::RefPtr<MimeMonitor> get();

  
  Glib::SignalProxy0< void > signal_data_changed();


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::
  virtual void on_data_changed();


};

} // namespace Vfs
} // namespace Gnome


namespace Glib
{
  /** @relates Gnome::Vfs::MimeMonitor
   * @param object The C instance
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   */
  Glib::RefPtr<Gnome::Vfs::MimeMonitor> wrap(GnomeVFSMIMEMonitor* object, bool take_copy = false);
}


#endif /* _LIBGNOMEVFSMM_MIME_MONITOR_H */

