// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _LIBGNOMEVFSMM_RESOLVE_HANDLE_H
#define _LIBGNOMEVFSMM_RESOLVE_HANDLE_H

#include <glibmm.h>

/* Copyright 2003 gnome-vfsmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <libgnomevfsmm/address.h>
#include <glibmm.h>
#include <libgnomevfs/gnome-vfs-resolve.h>


namespace Gnome
{

namespace Vfs
{

//The default constructor creates a null handle. Use resolve() before anything else.
class ResolveHandle
{
  public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  typedef ResolveHandle CppObjectType;
  typedef GnomeVFSResolveHandle BaseObjectType;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

private:


public:
  ResolveHandle();
  ~ResolveHandle();

  void resolve(const Glib::ustring& hostname);

  bool next_address(Address& address);
  void reset_to_beginning();

  GnomeVFSResolveHandle*       gobj()       { return gobject_; }
  const GnomeVFSResolveHandle* gobj() const { return gobject_; }
  GnomeVFSResolveHandle**      gobj_addr()  { return &gobject_; }

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  void assign_gobj(GnomeVFSResolveHandle* src);
#endif

protected:
  GnomeVFSResolveHandle* gobject_;

private:
  ResolveHandle(const ResolveHandle&);
  ResolveHandle& operator=(const ResolveHandle&);


};

} // namespace Vfs
} // namespace Gnome


#endif /* _LIBGNOMEVFSMM_RESOLVE_HANDLE_H */

