// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _LIBGNOMEVFSMM_TRANSFER_PROGRESS_P_H
#define _LIBGNOMEVFSMM_TRANSFER_PROGRESS_P_H
#endif /* _LIBGNOMEVFSMM_TRANSFER_PROGRESS_P_H */

