/* Copyright 2003 gnome-vfsmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef _LIBGNOMEVFSMM_PRIVATE_H
#define _LIBGNOMEVFSMM_PRIVATE_H

#include <glibmm.h>

#include <libgnomevfsmm/exception.h>
#include <libgnomevfs/gnome-vfs-result.h>

namespace Gnome
{

namespace Vfs
{

void handle_result(GnomeVFSResult result) throw(Gnome::Vfs::exception);

} // namespace Vfs
} // namespace Gnome

#endif /* _LIBGNOMEVFSMM_PRIVATE_H */
